@@ -2,7 +2,7 @@ package Rarbg::torrentapi;
 
 use strict;
 use 5.008_005;
-our $VERSION = 'v0.1.8';
+our $VERSION = 'v0.1.9';
 use LWP::UserAgent;
 use JSON;
 use Carp;
@@ -11,6 +11,7 @@ use Rarbg::torrentapi::Error;
 use Moose;
 
 our $BASEURL = 'https://torrentapi.org/pubapi_v2.php?';
+our $REQUEST_LIMIT = 2; # The api has a 1req/2s limit.
 
 has [qw(search_string search_imdb search_themoviedb search_tvdb category)] => (
     is  => 'rw',
@@ -82,11 +83,17 @@ has _token_time => (
     default => -1,
 );
 
+has _last_request => (
+    is      => 'rw',
+    isa     => 'Int',
+    default => -1
+);
+
 sub _renew_token {
     my $self = shift;
+    $self->_last_request(time);
     my $url  = $BASEURL . "get_token=get_token&app_id=" . $self->app_id;
     my $res_json = $self->_ua->get($url);
-    sleep 1;
     if ( $res_json->is_success ) {
         $self->_token_time(time);
         my $res = decode_json( $res_json->decoded_content );
@@ -104,9 +111,12 @@ sub _token_valid {
 
 sub _make_request {
     my $self = shift;
+    sleep $REQUEST_LIMIT if $self->_last_request != -1 && time - $self->_last_request < $REQUEST_LIMIT;
     unless ( $self->_token_valid ) {
         $self->_token( $self->_renew_token );
+        sleep $REQUEST_LIMIT;
     }
+    $self->_last_request(time);
     my $url = $BASEURL;
     foreach my $attribute ( $self->meta->get_attribute_list ) {
         next if $attribute =~ /^_/;
@@ -169,10 +179,10 @@ Rarbg::torrentapi - Wrapper around Rarbg torrentapi (L<https://torrentapi.org/ap
 
   use Rarbg::torrentapi;
   my $tapi = Rarbg::torrentapi->new();
-  
+
   # list lastest torrents
   my $last_added = $tapi->list();
-  
+
   # list torrents sorted by seeders
   my $last_added = $tapi->list({
       sort => 'seeders',
@@ -230,7 +240,56 @@ This is the Imdb id (http://imdb.com) in the form 'tt123456'
 
 Category can be quite confusing.
 It accepts 'tv' and 'movies'. But, for the rest of categories only accepts its id numbers (or a semi-colon separated list of them).
-Check Rarbg website to see what those are. They are not documented anywhere.
+
+=over 4
+
+=item * XXX (18+) => 4
+
+=item * Movies/XVID => 14
+
+=item * Movies/XVID/720 => 48
+
+=item * Movies/x264 => 17
+
+=item * Movies/x264/1080 => 44
+
+=item * Movies/x264/720 => 45
+
+=item * Movies/x264/3D => 47
+
+=item * Movies/x264/4k => 50
+
+=item * Movies/x265/4k => 51
+
+=item * Movies/x264/4k/HDR => 52
+
+=item * Movies/Full BD => 42
+
+=item * Movies/BD Remux => 46
+
+=item * TV Episodes => 18
+
+=item * TV HD Episodes => 41
+
+=item * TV UHD Episodes => 49
+
+=item * Movies/MP3 => 23
+
+=item * Movies/FLAC => 25
+
+=item * Games/PC ISO => 27
+
+=item * Games/PC RIP => 28
+
+=item * Games/PS3 => 40
+
+=item * Games/XBOX-360 => 32
+
+=item * Software/PC ISO => 33
+
+=item * Games/PS4 => 53
+
+=back
 
 =head2 limit
 
@@ -263,9 +322,10 @@ Makes a call to the API in 'search' mode. It returns either a Rarbg::torrentapi:
 
 Makes a call to the API in 'list' mode. It returns either a Rarbg::torrentapi::Error or an array of L<Rarbg::torrentapi::Res>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Paco Esteban E<lt>paco@onna.beE<gt>
+Baptiste C. L<https://github.com/baptistecdr>
 
 =head1 COPYRIGHT
 
